/*************************************************************/
/*  mcb.c Mandelbrot color program                           */
/*                                                           */
/*  Latest update: July 92  SS                               */
/*************************************************************/

/****************************************************************************/
/*                                                                           */
/* Notice:                                                                   */
/* =======                                                                   */
/*                                                                           */
/* I make no warranties that this program is (1) free of error, (2) con-     */
/* sistent with any standard merchantability, or (3) meeting the require-    */
/* ments of a particular application.  This software shall not, partly or    */
/* as a whole, participate in a process, whose outcome can result in injury  */
/* to a person or loss of property. It is solely designed for analytical     */
/* work.  Permission to use, copy, and distribute is hereby granted without  */
/* fee, providing that the header above including this notice appears in     */
/* all copies.                                                               */
/*                                                                           */
/*                                                         Stefan Spaennare  */
/*                                                                           */
/*****************************************************************************/


#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "image.h"


int main(argc,argv)
int argc;
char *argv[];
{
   struct image_head header;       
   short **image;

   double alfa,ss;
   int i,j,itmax,a,b,c,q,a2,b2,c2,q2,mod,itmaxcol;
   int col[32768];


   if (argc<2) {
      printf("Usage: %s image\n",argv[0]);
      exit(0);
   } /* if */

 
   ReadHeader(argv[1],&header);

   image = (short **)calloc(header.hgh,sizeof(short*));

   ReadImage(argv[1],image);



/* Head Program */


scanf("%d %d %d %d %d %d %lf %d",&q,&a,&b,&c,&itmax,&itmaxcol,&ss,&mod);


alfa=32767.0;


/* Color Table */


while (c <= itmax) {

if (mod==1) {
   for (i=q; i<=(q+a)/2; i++) {
      col[i]=(int)(alfa);
   }
   for (i=(q+a)/2+1; i<=a ; i++) {
      col[i]=(int)(alfa*(1.0-1.0/(double)(a-(q+a)/2-1)*(double)(i-(q+a)/2-1)));
   }
   for (i=a+1; i<=b; i++) {
     col[i]=0;
   }
   for (i=b+1; i<=(b+c)/2; i++) {
      col[i]=(int)(alfa/(double)((b+c)/2-b-1)*(double)(i-b-1));
   }
   for (i=(b+c)/2+1; i<=c; i++) {
      col[i]=(int)(alfa);
   }
} /* end mod 1 */

if (mod==2) {
   for (i=q; i<=(a+q)/2; i++) {
      col[i]=(int)(alfa/(double)((a+q)/2-q)*(double)(i-q));
   }
   for (i=(a+q)/2+1; i<=(a+b)/2; i++) {
      col[i]=(int)(alfa);
   }
   for (i=(a+b)/2+1; i<=b; i++) {
      col[i]=(int)(alfa*(1.0-1.0/(double)(b-(a+b)/2-1)*(double)(i-(a+b)/2-1)));
   }
   for (i=b+1; i<=c; i++) {
      col[i]=0;
   }
} /* end mod 2 */

if (mod==3) {
   for (i=q; i<=a; i++) {
      col[i]=0;
   }
   for (i=a+1; i<=(a+b)/2; i++) {
      col[i]=(int)(alfa/(double)((a+b)/2-a-1)*(double)(i-a-1));
   }
   for (i=(a+b)/2+1; i<=(b+c)/2; i++) {
      col[i]=(int)(alfa);
   }
   for (i=(b+c)/2+1; i<=c; i++) {
      col[i]=(int)(alfa*(1.0-1.0/(double)(c-(b+c)/2-1)*(double)(i-(b+c)/2-1)));
   }
} /* end mod 3 */

q2=q;
a2=a;
b2=b;
c2=c;

q=c2;
a=q+(int)(ss*(double)(a2-q2));
b=a+(int)(ss*(double)(b2-a2));
c=b+(int)(ss*(double)(c2-b2));

} /* while */

col[itmax]=alfa/255.0*itmaxcol;

/* Main Loop */


for (i=0; i<header.hgh; i++) {
   for (j=0; j<header.wid; j++) {
      image[i][j]=col[image[i][j]]; 
   } /* for j*/
} /* for i */


WriteImage(argv[1],image,header,im_s16);

} /* End */
